# Autogenerated by nbdev

d = { 'settings': { 'branch': 'main',
                'doc_baseurl': '/anndash',
                'doc_host': 'https://dsm-72.github.io',
                'git_url': 'https://github.com/dsm-72/anndash',
                'lib_path': 'anndash'},
  'syms': { 'anndash.core': { 'anndash.core.AnnDashboard': ('core.html#anndashboard', 'anndash/core.py'),
                              'anndash.core.AnnDashboard.__init__': ('core.html#anndashboard.__init__', 'anndash/core.py'),
                              'anndash.core.AnnDashboard._filter_keys': ('core.html#anndashboard._filter_keys', 'anndash/core.py'),
                              'anndash.core.AnnDashboard._make_callbacks': ('core.html#anndashboard._make_callbacks', 'anndash/core.py'),
                              'anndash.core.AnnDashboard._make_colors': ('core.html#anndashboard._make_colors', 'anndash/core.py'),
                              'anndash.core.AnnDashboard._make_drowdown': ('core.html#anndashboard._make_drowdown', 'anndash/core.py'),
                              'anndash.core.AnnDashboard._make_gene_items': ('core.html#anndashboard._make_gene_items', 'anndash/core.py'),
                              'anndash.core.AnnDashboard._make_layout': ('core.html#anndashboard._make_layout', 'anndash/core.py'),
                              'anndash.core.AnnDashboard._make_plot': ('core.html#anndashboard._make_plot', 'anndash/core.py'),
                              'anndash.core.AnnDashboard._make_radios': ('core.html#anndashboard._make_radios', 'anndash/core.py'),
                              'anndash.core.AnnDashboard._make_select': ('core.html#anndashboard._make_select', 'anndash/core.py'),
                              'anndash.core.AnnDashboard.run': ('core.html#anndashboard.run', 'anndash/core.py'),
                              'anndash.core.ColorDType': ('core.html#colordtype', 'anndash/core.py'),
                              'anndash.core.ColorDType.__call__': ('core.html#colordtype.__call__', 'anndash/core.py'),
                              'anndash.core.ColorDType._missing_': ('core.html#colordtype._missing_', 'anndash/core.py'),
                              'anndash.core.DTypePattern': ('core.html#dtypepattern', 'anndash/core.py'),
                              'anndash.core.DTypePattern.__call__': ('core.html#dtypepattern.__call__', 'anndash/core.py'),
                              'anndash.core.DTypePattern._missing_': ('core.html#dtypepattern._missing_', 'anndash/core.py'),
                              'anndash.core.DTypePattern.imatch': ('core.html#dtypepattern.imatch', 'anndash/core.py'),
                              'anndash.core.DTypePattern.match': ('core.html#dtypepattern.match', 'anndash/core.py'),
                              'anndash.core.DTypePattern.pattern': ('core.html#dtypepattern.pattern', 'anndash/core.py'),
                              'anndash.core.check_columns': ('core.html#check_columns', 'anndash/core.py'),
                              'anndash.core.check_values': ('core.html#check_values', 'anndash/core.py'),
                              'anndash.core.color_dtype': ('core.html#color_dtype', 'anndash/core.py'),
                              'anndash.core.default_env': ('core.html#default_env', 'anndash/core.py'),
                              'anndash.core.env_dependencies': ('core.html#env_dependencies', 'anndash/core.py'),
                              'anndash.core.extract_colors': ('core.html#extract_colors', 'anndash/core.py'),
                              'anndash.core.filter_imatches': ('core.html#filter_imatches', 'anndash/core.py'),
                              'anndash.core.filter_matches': ('core.html#filter_matches', 'anndash/core.py'),
                              'anndash.core.first_imatch': ('core.html#first_imatch', 'anndash/core.py'),
                              'anndash.core.first_match': ('core.html#first_match', 'anndash/core.py'),
                              'anndash.core.fullpath': ('core.html#fullpath', 'anndash/core.py'),
                              'anndash.core.guess_categorical': ('core.html#guess_categorical', 'anndash/core.py'),
                              'anndash.core.map_imatch': ('core.html#map_imatch', 'anndash/core.py'),
                              'anndash.core.map_match': ('core.html#map_match', 'anndash/core.py'),
                              'anndash.core.re_imatch': ('core.html#re_imatch', 'anndash/core.py'),
                              'anndash.core.str_imatch': ('core.html#str_imatch', 'anndash/core.py'),
                              'anndash.core.str_match': ('core.html#str_match', 'anndash/core.py'),
                              'anndash.core.subset_column_names': ('core.html#subset_column_names', 'anndash/core.py'),
                              'anndash.core.subset_columns': ('core.html#subset_columns', 'anndash/core.py')}}}
